@@ -44,14 +44,26 @@ sub configure {
 	push @flags, "-DCMAKE_VERBOSE_MAKEFILE=ON";
 
 	$this->mkdir_builddir();
-	$this->doit_in_builddir("cmake", $this->get_source_rel2builddir(), @flags, @_);
+	eval { 
+		$this->doit_in_builddir("cmake", $this->get_source_rel2builddir(), @flags, @_);
+	};
+	if ($@) {
+		if (-e $this->get_buildpath("CMakeCache.txt")) {
+			$this->doit_in_builddir("tail -v -n +0 CMakeCache.txt");
+		}
+		die $@;
+	}
 }
 
 sub test {
 	my $this=shift;
 
+	# Unlike make, CTest does not have "unlimited parallel" setting (-j implies
+	# -j1). So in order to simulate unlimited parallel, allow to fork a huge
+	# number of threads instead.
+	my $parallel = ($this->get_parallel() > 0) ? $this->get_parallel() : 999;
 	$ENV{CTEST_OUTPUT_ON_FAILURE} = 1;
-	return $this->SUPER::test(@_);
+	return $this->SUPER::test(@_, "ARGS+=-j$parallel");
 }
 
 1
